package model.questionnaire;

import model.personnality.Personality;
import model.personnality.Trait;

import java.util.HashMap;

/**
 * Stores answers provided for a session of answers
 */
public class SessionAnswers {

    private HashMap<Question, Answer> fAnswers;
    private HashMap<Trait, Float> fTraits;

    public SessionAnswers() {
        fTraits = new HashMap<>();
        fAnswers = new HashMap<>();
    }

    /**
     * Stores an answer to a question and updates the weight of the related trait.
     * If an answer has already been provided for the question, cancel the weight added by the outdated answer
     * @param iQuestion
     * @param iAnswer
     */
    public void setAnswer(Question iQuestion, Answer iAnswer) {
        // ---------------------------------
        // cancel the weight added by a potential previous answer
        // ---------------------------------
        if(fAnswers.containsKey(iQuestion)) {
            Answer vPreviousAnswer = fAnswers.get(iQuestion);
            Trait vPreviousTrait = vPreviousAnswer.getTrait();
            Float vOutdatedWeight = fTraits.get(vPreviousTrait);
            fTraits.put(vPreviousTrait, vOutdatedWeight - vPreviousAnswer.getWeight());
        }
        // ---------------------------------
        // Store the answer & update the related trait
        // ---------------------------------
        Trait vNewTrait = iAnswer.getTrait();
        Float vNewTraitWeight = iAnswer.getWeight();
        fAnswers.put(iQuestion, iAnswer);

        if(fTraits.containsKey(vNewTrait))
            vNewTraitWeight += fTraits.get(vNewTrait);

        fTraits.put(vNewTrait, vNewTraitWeight);
    }

}
