import React from 'react';
import url from '../server';
import Questionnaire from './questionnaire';

function Question(props){
    let current_question = props.questions[props.index];
    const [selectedAnswer, onSelectAnswer] = React.useState(current_question.answer);
    let question_answers = [];

    //-------------------------------
    // Build question form
    //-------------------------------
    current_question.answers.forEach(answer => {
        let dom_id = "answer"+answer.id
        question_answers.push(
            <div key={dom_id}>
                <input name="answer" id={dom_id} type="radio" value={answer.id} defaultChecked={answer.id === selectedAnswer}/>
                <label htmlFor={dom_id}>{answer.description}</label>
            </div>
        );
    });
    
    return (
    <div>
        <div> {current_question.name} </div>
        <div onChange={(value) => onSelectAnswer(value.target.value)}>
        {question_answers}
        </div>
        <div
            onClick={() => {
                //-------------------------------
                // POST question answer
                //-------------------------------
                fetch(url+"/session/"+props.sessionId, {
                    method:'PUT',
                    body: JSON.stringify({
                        question: current_question.id,
                        answer: selectedAnswer
                    }),
                    headers: {"Content-type": "application/json; charset=UTF-8"}
                }) 
                .then(response => response.json())
                .then(result => {
                    if(props.index === props.questions.length - 1)
                    {
                        //-------------------------------
                        // Tell the (parent) questionnaire that the results should be available
                        //-------------------------------
                        props.questionnaireCompleted(true);
                    }
                })
                .catch( e => console.error(e))

                if(props.index === props.questions.length - 1)
                {
                    current_question.answer = selectedAnswer;
                }
                else
                {
                    current_question.answer = selectedAnswer;
                    props.moveToQuestion(props.index + 1);
                }
            }}>
                {props.index < props.questions.length -1 ? "Validate" : "Get Results" }
        </div>
    </div>
    );
}

export default Question;